MultinomialEstimator
====================

.. currentmodule:: pqp.estimation

.. autoclass:: MultinomialEstimator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MultinomialEstimator.approx_difference
      ~MultinomialEstimator.approx_expectation
      ~MultinomialEstimator.approx_marginal
      ~MultinomialEstimator.approx_p
      ~MultinomialEstimator.approx_product
      ~MultinomialEstimator.approx_quotient
      ~MultinomialEstimator.domain_of
      ~MultinomialEstimator.domain_size
      ~MultinomialEstimator.estimate
      ~MultinomialEstimator.get_observed

   .. rubric:: Methods Documentation

   .. automethod:: approx_difference
   .. automethod:: approx_expectation
   .. automethod:: approx_marginal
   .. automethod:: approx_p
   .. automethod:: approx_product
   .. automethod:: approx_quotient
   .. automethod:: domain_of
   .. automethod:: domain_size
   .. automethod:: estimate
   .. automethod:: get_observed
